% In this demo code, we show how to compute the normalized image coordinates.

function main()

	% known intrinsic matrix of a camera
	K = [800, 0, 320;
		0, 800, 240;
		0, 0, 1];
		
	% ordinary coordinates in pixels
	ordPt = [300, 100]';

	% first version of normalization
	normPt_v1 = normalizePt_version_1(K, ordPt)

	% second version of normalization
	normPt_v2 = normalizePt_version_2(K, ordPt)

end


function normPt = normalizePt_version_1(K, ordPt)

    fu = K(1, 1);
    fv = K(2, 2);
    
	cu = K(1, 3);
	cv = K(2, 3);

	xn = (ordPt(1) - cu) / fu;
	yn = (ordPt(2) - cv) / fv;
    
    normPt = [xn; yn; 1]; % 1: distance from camera center to image plane

end

function normPt = normalizePt_version_2(K, ordPt)

    K_inv = inv(K);

    ordPt_homo = [ordPt; 1];

    normPt = K_inv * ordPt_homo;

end